..
    Copyright (C) 2020 CERN.

    Flask--Resources is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.


API Docs
========

Resources
---------

.. automodule:: flask_resources.resources
   :members:

Context
-------

.. automodule:: flask_resources.context
   :members: ResourceRequestCtx


Content negotiation and response handling
-----------------------------------------

.. automodule:: flask_resources.responses
   :members:

.. automodule:: flask_resources.content_negotiation
   :members:


Request body parsing
--------------------

.. automodule:: flask_resources.parsers
   :members: RequestBodyParser, request_body_parser


Request parsing
---------------

.. automodule:: flask_resources.parsers.base
    :members: RequestParser

.. automodule:: flask_resources.parsers.decorators
    :members: request_parser

Errors
-------------------------

.. automodule:: flask_resources.errors
    :members:

Serializers/deserializers
-------------------------

.. automodule:: flask_resources.serializers
    :members:

.. automodule:: flask_resources.deserializers
    :members:
